@@ -39,6 +39,7 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
+#include <stdlib.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -118,7 +119,7 @@ static void mixer_popup_show    (MixerData *data);
 static void mixer_popup_hide    (MixerData *data, gboolean revert);
 
 static void mixer_start_gmix_cb (BonoboUIComponent *uic,
-				 gpointer           data,
+				 MixerData         *data,
 				 const gchar       *verbname);
 
 void add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
@@ -334,11 +335,7 @@ mixer_update_slider (MixerData *data)
 {
 	gint vol = data->vol;
 
-	if (IS_PANEL_HORIZONTAL (data->orientation)) {
-		vol = -vol;
-	} else {
-		vol = vol - VOLUME_MAX;
-	}
+	vol = -vol;
 	
 	gtk_adjustment_set_value (data->adj, vol);
 }
@@ -346,10 +343,11 @@ mixer_update_slider (MixerData *data)
 static void
 mixer_update_image (MixerData *data)
 {
-	gint       vol;
-	GdkPixbuf *pixbuf;
+	gint vol, size;
+	GdkPixbuf *pixbuf, *copy = NULL, *new_pixbuf;
 
 	vol = data->vol;
+	size = panel_applet_get_size (PANEL_APPLET (data->applet));
 	
 	if (vol <= 0) {
 		pixbuf = zero_pixbuf;
@@ -364,10 +362,8 @@ mixer_update_image (MixerData *data)
 		pixbuf = max_pixbuf;
 	}
 
-	if (!data->mute) {
-		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), pixbuf);
-	} else {
-		GdkPixbuf *copy = gdk_pixbuf_copy (pixbuf);
+	if (data->mute) {
+		copy = gdk_pixbuf_copy (pixbuf);
 
 		gdk_pixbuf_composite (mute_pixbuf,
 				      copy,
@@ -381,10 +377,25 @@ mixer_update_image (MixerData *data)
 				      1.0,
 				      GDK_INTERP_BILINEAR,
 				      127);
-
-		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), copy);
-		g_object_unref (copy);
+		pixbuf = copy;
 	}
+
+	if (size == GNOME_Vertigo_PANEL_X_SMALL) {
+		/* Don't need to scale for this size */
+		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), pixbuf);
+		
+	}
+	else {
+		new_pixbuf = gdk_pixbuf_scale_simple (pixbuf,
+					size, size, GDK_INTERP_BILINEAR); 
+		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), new_pixbuf);
+		g_object_unref (new_pixbuf);
+	}
+	
+	gtk_widget_set_size_request (GTK_WIDGET (data->frame),
+                                     MAX (11, size-1),MAX (11, size-1));
+        if (copy)
+        	g_object_unref (copy);
 }
 
 static gboolean
@@ -468,14 +479,32 @@ applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *dat
 
 
 static gboolean
-applet_scroll_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data)
+applet_scroll_event_cb (GtkWidget *widget, GdkEventScroll *event, MixerData *data)
 {
-       if (event->type = GDK_SCROLL) {
-               if (data->popup == NULL)
-                       mixer_popup_show (data);
-               return TRUE;
-       }
-       return FALSE;
+	gint direction; 
+	if (event->type != GDK_SCROLL ) {
+		return FALSE;
+	}
+
+	direction = event->direction;
+
+	switch(direction) {
+	case GDK_SCROLL_UP:
+		data->vol += 5;
+		break;
+	case GDK_SCROLL_DOWN:
+		data->vol -= 5;
+		break;
+	default:
+		break;
+	}
+
+	if (data->vol > VOLUME_MAX) data->vol = VOLUME_MAX;
+	if (data->vol < 0) data->vol = 0;
+
+	mixer_update_slider(data);
+
+	return TRUE;
 }
 
 static void
@@ -676,6 +705,7 @@ applet_change_background_cb (PanelApplet               *applet,
 		GtkRcStyle *rc_style = gtk_rc_style_new ();
 
 		gtk_widget_modify_style (data->applet, rc_style);
+		gtk_rc_style_unref (rc_style);
 	}
 	else if (type == PANEL_COLOR_BACKGROUND) {
 		gtk_widget_modify_bg (data->applet,
@@ -697,64 +727,82 @@ applet_change_orient_cb (GtkWidget *w, PanelAppletOrient o, MixerData *data)
 static void
 applet_change_size_cb (GtkWidget *w, gint size, MixerData *data)
 {
-	gint vol;
-
 	mixer_popup_hide (data, FALSE);
-
-	/* Really only needed to fit on the ultra small panel,
-	 * but we could scale up for the bigger ones...
-	 */
-	if (IS_PANEL_HORIZONTAL (data->orientation)) {
-		gtk_widget_set_size_request (GTK_WIDGET (data->frame),
-					     23,
-					     MIN (23, size));
-	} else {
-		gtk_widget_set_size_request (GTK_WIDGET (data->frame),
-					     MIN (23, size),
-					     23);
-	}
+	mixer_update_image (data);
 }
 
 static void
 mixer_start_gmix_cb (BonoboUIComponent *uic,
-		     gpointer           data,
+		     MixerData         *data,
 		     const gchar       *verbname)
 {
 	GError *error = NULL;
-	
-	if (run_mixer_cmd)
-		g_spawn_command_line_async (run_mixer_cmd, &error);
-		
+
+	if (!run_mixer_cmd)
+		return;
+
+	g_spawn_command_line_async (run_mixer_cmd, &error);
 	if (error) {
-		g_print ("%s \n", error->message);
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("There was an error executing '%s' : %s"),
+						 run_mixer_cmd,
+						 error->message);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+		gtk_widget_show (dialog);
+
 		g_error_free (error);
 	}
 }
 
 static void
 mixer_about_cb (BonoboUIComponent *uic,
-		gpointer           data,
+		MixerData         *data,
 		const gchar       *verbname)
 {
         static GtkWidget   *about     = NULL;
+        GdkPixbuf *pixbuf             = NULL;
+        gchar *file;
         static const gchar *authors[] = {
 		"Richard Hult <rhult@codefactory.se>",
                 NULL
         };
 
-        if (about != NULL) {
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+	
+        if (about) {
                 gtk_window_present (GTK_WINDOW (about));
                 return;
         }
+        
+        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mixer-applet.png", TRUE, NULL);
+        pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+        g_free (file);
 
         about = gnome_about_new (_("Volume Control"), VERSION,
                                  _("(C) 2001 Richard Hult"),
                                  _("The volume control lets you set the volume level for your desktop."),
 				 authors,
-				 NULL,
-				 NULL,
-                                 NULL);
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                                 pixbuf);
 
+	gtk_window_set_wmclass (GTK_WINDOW(about), "volume control", "Volume Control");
+	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-mixer-applet.png");
         g_signal_connect (G_OBJECT (about), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
 	                  &about);
@@ -767,14 +815,14 @@ mixer_help_cb (BonoboUIComponent *uic,
 	       gpointer           data,
 	       const gchar       *verbname)
 {
-#if 0
-	GnomeHelpMenuEntry help_entry = {
-		"volume-control-applet",
-		"index.html"
-	};
-
-	gnome_help_display (NULL, &help_entry);
-#endif
+        GError *error = NULL;
+        
+	gnome_help_display("mixer_applet2",NULL,&error);
+	if (error) {
+		g_print ("%s \n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
 }
 
 /* Dummy callback to get rid of a warning, for now. */
@@ -841,10 +889,10 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 }
 
 const BonoboUIVerb mixer_applet_menu_verbs [] = {
-	BONOBO_UI_VERB ("RunMixer", mixer_start_gmix_cb),
-	BONOBO_UI_VERB ("Mute",     mixer_mute_cb),
-	BONOBO_UI_VERB ("Help",     mixer_help_cb),
-	BONOBO_UI_VERB ("About",    mixer_about_cb),
+	BONOBO_UI_UNSAFE_VERB ("RunMixer", mixer_start_gmix_cb),
+	BONOBO_UI_UNSAFE_VERB ("Mute",     mixer_mute_cb),
+	BONOBO_UI_UNSAFE_VERB ("Help",     mixer_help_cb),
+	BONOBO_UI_UNSAFE_VERB ("About",    mixer_about_cb),
 	
         BONOBO_UI_VERB_END
 };
@@ -856,6 +904,9 @@ mixer_applet_create (PanelApplet *applet)
 	BonoboUIComponent *component;
 	const gchar *device;
 	gboolean retval;
+#ifdef SUN_API
+	gchar *ctl = NULL;
+#endif
 
 #ifdef OSS_API
 	/* /dev/sound/mixer for devfs */
@@ -867,7 +918,9 @@ mixer_applet_create (PanelApplet *applet)
 	}
 #endif
 #ifdef SUN_API
-	device = "/dev/audioctl";
+	if (!(ctl = g_getenv("AUDIODEV")))
+		ctl = "/dev/audio";
+	device = g_strdup_printf("%sctl",ctl);
 	retval = openMixer(device);
 #endif
 
@@ -898,7 +951,7 @@ mixer_applet_create (PanelApplet *applet)
 	/* Try to find some mixers - sdtaudiocontrol is on Solaris and is needed
 	** because gnome-volume-meter doesn't work */
 	if (run_mixer_cmd == NULL) 
-		run_mixer_cmd = g_find_program_in_path ("gnome-volume-meter");
+		run_mixer_cmd = g_find_program_in_path ("gnome-volume-control");
 	if (run_mixer_cmd == NULL) 
 		run_mixer_cmd = g_find_program_in_path ("gmix");
 	if (run_mixer_cmd == NULL) 
@@ -1025,7 +1078,7 @@ mixer_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MixerApplet_Factory",
 			     PANEL_TYPE_APPLET,
-			     "Volume control applet",
+			     "mixer_applet2",
 			     "0",
 			     mixer_applet_factory,
 			     NULL)
