@@ -75,7 +75,7 @@ property_toggled_cb(GtkWidget *widget, gpointer name)
 	
 	if (active)
 	{
-		for (i = 0; i < 5; i++)
+		for (i = 0; i < 4; i++)
 			gtk_widget_set_sensitive(ma->check_boxes[i], TRUE);	
 		gtk_widget_show_all (ma->graphs[prop_type]->main_widget);
 		ma->graphs[prop_type]->visible = TRUE;
@@ -215,6 +215,8 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 	gint red, green, blue;
 	
 	color_string = panel_applet_gconf_get_string(ma->applet, gconf_path, NULL);
+	if (!color_string)
+		color_string = g_strdup ("#000000");
 	red = g_ascii_xdigit_value(color_string[1]) * 16 + g_ascii_xdigit_value(color_string[2]);
 	green = g_ascii_xdigit_value(color_string[3]) * 16 + g_ascii_xdigit_value(color_string[4]);
 	blue = g_ascii_xdigit_value(color_string[5]) * 16 + g_ascii_xdigit_value(color_string[6]);
@@ -395,21 +397,22 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 
 /* show properties dialog */
 void
-multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name)
+multiload_properties_cb (BonoboUIComponent *uic,
+			 MultiloadApplet   *ma,
+			 const char        *name)
 {
-	MultiloadApplet *ma;
 	static GtkWidget *dialog = NULL;
 	
-	if (dialog != NULL)
-	{
+	if (dialog) {
 	    gtk_window_present (GTK_WINDOW (dialog));
 	    return;
 	}
 	
-	ma = (MultiloadApplet *)data;
-	
-	dialog = gtk_dialog_new_with_buttons(_("System Monitor Preferences"), NULL, 0, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
-				
+	dialog = gtk_dialog_new_with_buttons (_("System Monitor Preferences"),
+					      NULL, 0,
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					      NULL);
+
 	fill_properties(dialog, ma);
 
 	properties_set_insensitive(ma);
